@@ -560,3 +560,467 @@ void auto_exposure_algorithm::histogram_score(std::vector<int>& h, const int tot
         score.main_std = 0.0f;
     }
 }
+
+rect_gaussian_dots_target_calculator::rect_gaussian_dots_target_calculator(int width, int height, int roi_start_x, int roi_start_y, int roi_width, int roi_height)
+    : _full_width(width), _full_height(height), _roi_start_x(roi_start_x), _roi_start_y(roi_start_y), _width(roi_width), _height(roi_height)
+{
+    _wt = _width - _tsize;
+    _ht = _height - _tsize;
+    _size = _width * _height;
+
+    _hwidth = _width >> 1;
+    _hheight = _height >> 1;
+
+    _imgt.resize(_tsize2);
+    _img.resize(_size);
+    _ncc.resize(_size);
+    memset(_ncc.data(), 0, _size * sizeof(double));
+
+    _buf.resize(_patch_size);
+}
+
+rect_gaussian_dots_target_calculator::~rect_gaussian_dots_target_calculator()
+{
+}
+
+bool rect_gaussian_dots_target_calculator::calculate(const uint8_t* img, float* target_dims, unsigned int target_dims_size)
+{
+    bool ret = false;
+    if (target_dims_size < 4)
+        return ret;
+
+    normalize(img);
+    calculate_ncc();
+
+    if (find_corners())
+        ret = validate_corners(img);
+
+    if (ret)
+    {
+        if (target_dims_size == 4)
+            calculate_rect_sides(target_dims);
+        else if (target_dims_size == 8)
+        {
+            int j = 0;
+            for (int i = 0; i < 4; ++i)
+            {
+                target_dims[j++] = static_cast<float>(_corners[i].x + _roi_start_x);
+                target_dims[j++] = static_cast<float>(_corners[i].y + _roi_start_y);
+            }
+        }
+    }
+
+    return ret;
+}
+
+void rect_gaussian_dots_target_calculator::normalize(const uint8_t* img)
+{
+    uint8_t min_val = 255;
+    uint8_t max_val = 0;
+
+    int jumper = _full_width - _width;
+    const uint8_t* p = img + _roi_start_y * _full_width + _roi_start_x;
+    for (int j = 0; j < _height; ++j)
+    {
+        for (int i = 0; i < _width; ++i)
+        {
+            if (*p < min_val)
+                min_val = *p;
+
+            if (*p > max_val)
+                max_val = *p;
+
+            ++p;
+        }
+
+        p += jumper;
+    }
+
+    if (max_val > min_val)
+    {
+        double factor = 1.0 / (max_val - min_val);
+
+        p = img;
+        double* q = _img.data();
+        p = img + _roi_start_y * _full_width + _roi_start_x;
+        for (int j = 0; j < _height; ++j)
+        {
+            for (int i = 0; i < _width; ++i)
+                *q++ = 1.0 - (*p++ - min_val) * factor;
+
+            p += jumper;
+        }
+    }
+}
+
+void rect_gaussian_dots_target_calculator::calculate_ncc()
+{
+    double* pncc = _ncc.data() + (_htsize * _width + _htsize);
+    double* pi = _img.data();
+    double* pit = _imgt.data();
+
+    const double* pt = nullptr;
+    const double* qi = nullptr;
+
+    double sum = 0.0;
+    double mean = 0.0;
+    double norm = 0.0;
+
+    double min_val = 2.0;
+    double max_val = -2.0;
+    double tmp = 0.0;
+
+    for (int j = 0; j < _ht; ++j)
+    {
+        for (int i = 0; i < _wt; ++i)
+        {
+            qi = pi;
+            sum = 0.0f;
+            for (int m = 0; m < _tsize; ++m)
+            {
+                for (int n = 0; n < _tsize; ++n)
+                    sum += *qi++;
+
+                qi += _wt;
+            }
+
+            mean = sum / _tsize2;
+
+            qi = pi;
+            sum = 0.0f;
+            pit = _imgt.data();
+            for (int m = 0; m < _tsize; ++m)
+            {
+                for (int n = 0; n < _tsize; ++n)
+                {
+                    *pit = *qi++ - mean;
+                    sum += *pit * *pit;
+                    ++pit;
+                }
+                qi += _wt;
+            }
+
+            norm = sqrt(sum);
+
+            pt = _template.data();
+            pit = _imgt.data();
+            sum = 0.0;
+            for (int k = 0; k < _tsize2; ++k)
+                sum += *pit++ * *pt++;
+
+            tmp = sum / norm;
+            if (tmp < min_val)
+                min_val = tmp;
+
+            if (tmp > max_val)
+                max_val = tmp;
+
+            *pncc++ = tmp;
+            ++pi;
+        }
+
+        pncc += _tsize;
+        pi += _tsize;
+    }
+
+    if (max_val > min_val)
+    {
+        double factor = 1.0 / (max_val - min_val);
+        double div = 1.0 - _thresh;
+        pncc = _ncc.data();
+        for (int i = 0; i < _size; ++i)
+        {
+            tmp = (*pncc - min_val) * factor;
+            *pncc++ = (tmp < _thresh ? 0 : (tmp - _thresh) / div);
+        }
+    }
+}
+
+bool rect_gaussian_dots_target_calculator::find_corners()
+{
+    static const int edge = 20;
+
+    // upper left
+    _pts[0].x = 0;
+    _pts[0].y = 0;
+    double peak = 0.0f;
+    double* p = _ncc.data() + _htsize * _width;
+    for (int j = _htsize; j < _hheight; ++j)
+    {
+        p += _htsize;
+        for (int i = _htsize; i < _hwidth; ++i)
+        {
+            if (*p > peak)
+            {
+                peak = *p;
+                _pts[0].x = i;
+                _pts[0].y = j;
+            }
+            ++p;
+        }
+        p += _hwidth;
+    }
+
+    if (peak < _thresh || _pts[0].x < edge || _pts[0].y < edge)
+        return false;
+
+    // upper right
+    _pts[1].x = 0;
+    _pts[1].y = 0;
+    peak = 0.0f;
+    p = _ncc.data() + _htsize * _width;
+    for (int j = _htsize; j < _hheight; ++j)
+    {
+        p += _hwidth;
+        for (int i = _hwidth; i < _width - _htsize; ++i)
+        {
+            if (*p > peak)
+            {
+                peak = *p;
+                _pts[1].x = i;
+                _pts[1].y = j;
+            }
+            ++p;
+        }
+        p += _htsize;
+    }
+
+    if (peak < _thresh || _pts[1].x + edge > _width || _pts[1].y < edge || _pts[1].x - _pts[0].x < edge)
+        return false;
+
+    // lower left
+    _pts[2].x = 0;
+    _pts[2].y = 0;
+    peak = 0.0f;
+    p = _ncc.data() + _hheight * _width;
+    for (int j = _hheight; j < _height - _htsize; ++j)
+    {
+        p += _htsize;
+        for (int i = _htsize; i < _hwidth; ++i)
+        {
+            if (*p > peak)
+            {
+                peak = *p;
+                _pts[2].x = i;
+                _pts[2].y = j;
+            }
+            ++p;
+        }
+        p += _hwidth;
+    }
+
+    if (peak < _thresh || _pts[2].x < edge || _pts[2].y + edge > _height || _pts[2].y - _pts[1].y < edge)
+        return false;
+
+    // lower right
+    _pts[3].x = 0;
+    _pts[3].y = 0;
+    peak = 0.0f;
+    p = _ncc.data() + _hheight * _width;
+    for (int j = _hheight; j < _height - _htsize; ++j)
+    {
+        p += _hwidth;
+        for (int i = _hwidth; i < _width - _htsize; ++i)
+        {
+            if (*p > peak)
+            {
+                peak = *p;
+                _pts[3].x = i;
+                _pts[3].y = j;
+            }
+            ++p;
+        }
+        p += _htsize;
+    }
+
+    if (peak < _thresh || _pts[3].x + edge > _width || _pts[3].y + edge > _height || _pts[3].x - _pts[2].x < edge || _pts[3].y - _pts[1].y < edge)
+        return false;
+    else
+        refine_corners();
+
+    return true;
+}
+
+void rect_gaussian_dots_target_calculator::refine_corners()
+{
+    double* f = _buf.data();
+    int hs = _patch_size >> 1;
+
+    // upper left
+    int pos = (_pts[0].y - hs) * _width + _pts[0].x - hs;
+
+    _corners[0].x = static_cast<double>(_pts[0].x - hs);
+    minimize_x(_ncc.data() + pos, _patch_size, f, _corners[0].x);
+
+    _corners[0].y = static_cast<double>(_pts[0].y - hs);
+    minimize_y(_ncc.data() + pos, _patch_size, f, _corners[0].y);
+
+    // upper right
+    pos = (_pts[1].y - hs) * _width + _pts[1].x - hs;
+
+    _corners[1].x = static_cast<double>(_pts[1].x - hs);
+    minimize_x(_ncc.data() + pos, _patch_size, f, _corners[1].x);
+
+    _corners[1].y = static_cast<double>(_pts[1].y - hs);
+    minimize_y(_ncc.data() + pos, _patch_size, f, _corners[1].y);
+
+    // lower left
+    pos = (_pts[2].y - hs) * _width + _pts[2].x - hs;
+
+    _corners[2].x = static_cast<double>(_pts[2].x - hs);
+    minimize_x(_ncc.data() + pos, _patch_size, f, _corners[2].x);
+
+    _corners[2].y = static_cast<double>(_pts[2].y - hs);
+    minimize_y(_ncc.data() + pos, _patch_size, f, _corners[2].y);
+
+    // lower right
+    pos = (_pts[3].y - hs) * _width + _pts[3].x - hs;
+
+    _corners[3].x = static_cast<double>(_pts[3].x - hs);
+    minimize_x(_ncc.data() + pos, _patch_size, f, _corners[3].x);
+
+    _corners[3].y = static_cast<double>(_pts[3].y - hs);
+    minimize_y(_ncc.data() + pos, _patch_size, f, _corners[3].y);
+}
+
+bool rect_gaussian_dots_target_calculator::validate_corners(const uint8_t* img)
+{
+    static const int pos_diff_threshold = 4;
+    if (abs(_corners[0].x - _corners[2].x) > pos_diff_threshold ||
+        abs(_corners[1].x - _corners[3].x) > pos_diff_threshold ||
+        abs(_corners[0].y - _corners[1].y) > pos_diff_threshold ||
+        abs(_corners[2].y - _corners[3].y) > pos_diff_threshold)
+    {
+        return false;
+    }
+
+    return true;
+}
+
+void rect_gaussian_dots_target_calculator::calculate_rect_sides(float* rect_sides)
+{
+    double lx = _corners[1].x - _corners[0].x;
+    double ly = _corners[1].y - _corners[0].y;
+    rect_sides[0] = static_cast<float>(sqrt(lx * lx + ly * ly)); // uppper
+
+    lx = _corners[3].x - _corners[2].x;
+    ly = _corners[3].y - _corners[2].y;
+    rect_sides[1] = static_cast<float>(sqrt(lx * lx + ly * ly)); // lower
+
+    lx = _corners[2].x - _corners[0].x;
+    ly = _corners[2].y - _corners[0].y;
+    rect_sides[2] = static_cast<float>(sqrt(lx * lx + ly * ly)); // left
+
+    lx = _corners[3].x - _corners[1].x;
+    ly = _corners[3].y - _corners[1].y;
+    rect_sides[3] = static_cast<float>(sqrt(lx * lx + ly * ly)); // right
+}
+
+void rect_gaussian_dots_target_calculator::minimize_x(const double* p, int s, double* f, double& x)
+{
+    int ws = _width - s;
+
+    for (int i = 0; i < s; ++i)
+        f[i] = 0;
+
+    for (int j = 0; j < s; ++j)
+    {
+        for (int i = 0; i < s; ++i)
+            f[i] += *p++;
+        p += ws;
+    }
+
+    x += subpixel_agj(f, s);
+}
+
+void rect_gaussian_dots_target_calculator::minimize_y(const double* p, int s, double* f, double& y)
+{
+    int ws = _width - s;
+
+    for (int i = 0; i < s; ++i)
+        f[i] = 0;
+
+    for (int j = 0; j < s; ++j)
+    {
+        for (int i = 0; i < s; ++i)
+            f[j] += *p++;
+        p += ws;
+    }
+
+    y += subpixel_agj(f, s);
+}
+
+double rect_gaussian_dots_target_calculator::subpixel_agj(double* f, int s)
+{
+    int mi = 0;
+    double mv = f[mi];
+    for (int i = 1; i < s; ++i)
+    {
+        if (f[i] > mv)
+        {
+            mi = i;
+            mv = f[mi];
+        }
+    }
+
+    double half_mv = 0.5f * mv;
+
+    int x_0 = 0;
+    int x_1 = 0;
+    for (int i = 0; i < s; ++i)
+    {
+        if (f[i] > half_mv)
+        {
+            x_1 = i;
+            break;
+        }
+    }
+
+    double left_mv = 0.0f;
+    if (x_1 > 0)
+    {
+        x_0 = x_1 - 1;
+        left_mv = x_0 + (half_mv - f[x_0]) / (f[x_1] - f[x_0]);
+    }
+    else
+        left_mv = static_cast<double>(0);
+
+    x_0 = s - 1;
+    for (int i = s - 1; i >= 0; --i)
+    {
+        if (f[i] > half_mv)
+        {
+            x_0 = i;
+            break;
+        }
+    }
+
+    double right_mv = 0.0f;
+    if (x_0 == s - 1)
+        right_mv = static_cast<double>(s - 1);
+    else
+    {
+        x_1 = x_0 + 1;
+        right_mv = x_0 + (half_mv - f[x_0]) / (f[x_1] - f[x_0]);
+    }
+
+    return (left_mv + right_mv) / 2;
+}
+
+// return 1 if target pattern is found and its location is calculated, zero otherwise.
+int rect_calculator::extract_target_dims(const rs2_frame* frame_ref, float4& rect_sides)
+{
+    int ret = 0;
+    rs2_error* e = nullptr;
+
+    //Target dimension array size is predefined. 4 for RS2_CALIB_TARGET_RECT_GAUSSIAN_DOT_VERTICES and 8 for RS2_CALIB_TARGET_POS_GAUSSIAN_DOT_VERTICES.
+    int dim_size = _roi ? 4 : 8;
+    rs2_calib_target_type tgt_type = _roi ? RS2_CALIB_TARGET_ROI_RECT_GAUSSIAN_DOT_VERTICES : RS2_CALIB_TARGET_RECT_GAUSSIAN_DOT_VERTICES;
+    rs2_extract_target_dimensions(frame_ref, tgt_type, reinterpret_cast<float*>(&rect_sides), dim_size, &e);
+    if (e == nullptr)
+    {
+        ret = 1;
+    }
+
+    return ret;
+}
